@@ -37,7 +37,7 @@ class RecordDefine:
         elif record_type == BasicType.ByteArray:
             proto.bytes_field = value
         elif record_type == BasicType.String:
-            proto.string_field = value
+            proto.bytes_field = value.encode()
         elif record_type == BasicType.Float:
             proto.float64_field = value
         else:
@@ -63,7 +63,7 @@ class RecordDefine:
         elif record_type == BasicType.Float:
             return feature.float64_field
         elif record_type == BasicType.String:
-            return feature.string_field
+            return feature.bytes_field.decode()
         else:
             raise Exception("Type `{}` not supported".format(record_type))
 
